from pydantic import BaseModel, EmailStr
from typing import Optional


# Schema for user registration
class UserCreate(BaseModel):
    username: str
    email: EmailStr
    password: str


# Schema for user login
class UserLogin(BaseModel):
    email: EmailStr
    password: str


# Schema for response after user registration or login
class UserResponse(BaseModel):
    id: int
    username: str
    email: EmailStr
    role: str  # "buyer", "shop_owner", "admin"

    class Config:
        from_attributes = True  # Enables ORM mode for SQLModel compatibility


# Schema for updating user profile
class UserUpdate(BaseModel):
    username: Optional[str] = None
    email: Optional[EmailStr] = None
    password: Optional[str] = None
